import React, { useState, useEffect } from 'react';
import { Table, Input, Button, Space } from 'antd';
import { SearchOutlined } from '@ant-design/icons';

interface Item {
  id: number;
  name: string;
  code: string;
  quantity: number;
  category: string;
}

const ItemsList: React.FC = () => {
  const [items, setItems] = useState<Item[]>([]);
  const [loading, setLoading] = useState(false);
  const [searchText, setSearchText] = useState('');

  useEffect(() => {
    fetchItems();
  }, []);

  const fetchItems = async () => {
    setLoading(true);
    try {
      const response = await fetch('/api/items');
      const data = await response.json();
      setItems(data);
    } catch (error) {
      console.error('Ошибка при загрузке товаров:', error);
    } finally {
      setLoading(false);
    }
  };

  const columns = [
    {
      title: 'Название',
      dataIndex: 'name',
      key: 'name',
      sorter: (a: Item, b: Item) => a.name.localeCompare(b.name),
    },
    {
      title: 'Код',
      dataIndex: 'code',
      key: 'code',
    },
    {
      title: 'Количество',
      dataIndex: 'quantity',
      key: 'quantity',
      sorter: (a: Item, b: Item) => a.quantity - b.quantity,
    },
    {
      title: 'Категория',
      dataIndex: 'category',
      key: 'category',
      filters: [
        { text: 'Запчасти', value: 'Запчасти' },
        { text: 'Топливо', value: 'Топливо' },
        { text: 'Масла', value: 'Масла' },
      ],
    },
  ];

  return (
    <div className="items-list">
      <Space style={{ marginBottom: 16 }}>
        <Input
          placeholder="Поиск товаров"
          prefix={<SearchOutlined />}
          value={searchText}
          onChange={e => setSearchText(e.target.value)}
        />
        <Button type="primary" onClick={() => fetchItems()}>
          Обновить
        </Button>
      </Space>
      <Table
        columns={columns}
        dataSource={items}
        loading={loading}
        rowKey="id"
        pagination={{ pageSize: 10 }}
      />
    </div>
  );
};

export default ItemsList; 